@@ -1,10 +1,10 @@
-use std::io::Write;
-use std::os::raw::c_char;
+use crate::error::ErrorKind;
 use std::ffi::CStr;
 use std::fmt;
-use std::io;
 use std::fs::File;
-use crate::error::ErrorKind;
+use std::io;
+use std::io::Write;
+use std::os::raw::c_char;
 
 use crate::ThBufReader;
 
@@ -156,28 +156,48 @@ pub enum Chunk {
     TeamPractice {
         team: i32,
         practice: i32,
-    }
+    },
+    PlayerReady {
+        cid: i32,
+    },
 }
 
-use crate::chunks::{Chunk as ChunkRust};
+use crate::chunks::Chunk as ChunkRust;
 
 impl Teehistorian {
     fn convert_chunk(chunk: &ChunkRust, args_buf: &mut Vec<*const c_char>) -> Chunk {
         match chunk {
-            ChunkRust::PlayerDiff(p) => Chunk::PlayerDiff { cid: p.cid, dx: p.dx, dy: p.dy },
+            ChunkRust::PlayerDiff(p) => Chunk::PlayerDiff {
+                cid: p.cid,
+                dx: p.dx,
+                dy: p.dy,
+            },
             ChunkRust::Eos => Chunk::Eos,
             ChunkRust::TickSkip(t) => Chunk::TickSkip { dt: t.dt },
-            ChunkRust::PlayerNew(p) => Chunk::PlayerNew { cid: p.cid, x: p.x, y: p.y },
+            ChunkRust::PlayerNew(p) => Chunk::PlayerNew {
+                cid: p.cid,
+                x: p.x,
+                y: p.y,
+            },
             ChunkRust::PlayerOld(p) => Chunk::PlayerOld { cid: p.cid },
-            ChunkRust::InputDiff(i) => Chunk::InputDiff { cid: i.cid, dinput: i.dinput.clone() },
-            ChunkRust::InputNew(i) => Chunk::InputNew { cid: i.cid, input: i.input.clone() },
+            ChunkRust::InputDiff(i) => Chunk::InputDiff {
+                cid: i.cid,
+                dinput: i.dinput.clone(),
+            },
+            ChunkRust::InputNew(i) => Chunk::InputNew {
+                cid: i.cid,
+                input: i.input.clone(),
+            },
             ChunkRust::NetMessage(n) => Chunk::NetMessage {
                 cid: n.cid,
                 size: n.msg.len() as i32,
                 msg: n.msg.as_ptr() as *const c_char,
             },
             ChunkRust::Join(p) => Chunk::Join { cid: p.cid },
-            ChunkRust::Drop(p) => Chunk::Drop { cid: p.cid, reason: p.reason.as_ptr() as *const c_char },
+            ChunkRust::Drop(p) => Chunk::Drop {
+                cid: p.cid,
+                reason: p.reason.as_ptr() as *const c_char,
+            },
             ChunkRust::ConsoleCommand(c) => {
                 *args_buf = c.args.iter().map(|s| s.as_ptr() as *const c_char).collect();
                 Chunk::ConsoleCommand {
@@ -187,7 +207,7 @@ impl Teehistorian {
                     num_args: c.num_args,
                     args: args_buf.as_ptr(),
                 }
-            },
+            }
             ChunkRust::UnknownEx(e) => Chunk::UnknownEx {
                 uuid: *e.uuid.as_bytes(),
                 size: e.size,
@@ -214,9 +234,7 @@ impl Teehistorian {
                 level: a.level,
                 auth_name: a.auth_name.as_ptr() as *const c_char,
             },
-            ChunkRust::AuthLogout(a) => Chunk::AuthLogout {
-                cid: a.cid
-            },
+            ChunkRust::AuthLogout(a) => Chunk::AuthLogout { cid: a.cid },
             ChunkRust::JoinVer6(p) => Chunk::JoinVer6 { cid: p.cid },
             ChunkRust::JoinVer7(p) => Chunk::JoinVer7 { cid: p.cid },
             ChunkRust::TeamSaveSuccess(s) => Chunk::TeamSaveSuccess {
@@ -224,17 +242,13 @@ impl Teehistorian {
                 save_id: *s.save_id.as_bytes(),
                 save: s.save.as_ptr() as *const c_char,
             },
-            ChunkRust::TeamSaveFailure(s) => Chunk::TeamSaveFailure {
-                team: s.team,
-            },
+            ChunkRust::TeamSaveFailure(s) => Chunk::TeamSaveFailure { team: s.team },
             ChunkRust::TeamLoadSuccess(s) => Chunk::TeamLoadSuccess {
                 team: s.team,
                 save_id: *s.save_id.as_bytes(),
                 save: s.save.as_ptr() as *const c_char,
             },
-            ChunkRust::TeamLoadFailure(s) => Chunk::TeamLoadFailure {
-                team: s.team,
-            },
+            ChunkRust::TeamLoadFailure(s) => Chunk::TeamLoadFailure { team: s.team },
             ChunkRust::PlayerTeam(pt) => Chunk::PlayerTeam {
                 cid: pt.cid,
                 team: pt.team,
@@ -243,6 +257,7 @@ impl Teehistorian {
                 team: tp.team,
                 practice: tp.practice,
             },
+            ChunkRust::PlayerReady(p) => Chunk::PlayerReady { cid: p.cid },
         }
     }
 }
@@ -269,7 +284,7 @@ pub enum ThResult {
 impl LastReturn {
     fn handle_error(&mut self, error: crate::Error) -> ThResult {
         self.value = match error {
-             crate::Error::ParseError(err) => {
+            crate::Error::ParseError(err) => {
                 self.error = Error::ParseError(err);
                 ThResult::ThParseError
             }
@@ -292,7 +307,6 @@ impl LastReturn {
     }
 }
 
-
 /// Opening A Teehistorian File
 ///
 /// Whether or not an error occurs when it is opened, resources associated with the teehistorian
@@ -313,14 +327,22 @@ pub extern "C" fn th_open(filename: *const c_char, th: &mut *mut Teehistorian) -
     });
     let mut new_th = Box::leak(new_th);
     *th = new_th;
-    let filename = unsafe { CStr::from_ptr( filename as *const i8) };
+    let filename = unsafe { CStr::from_ptr(filename as *const i8) };
     let filename = match filename.to_str() {
         Ok(f) => f,
-        Err(err) => return new_th.last_return.on_return(ThResult::ThIoError, Error::Utf8Error(err)),
+        Err(err) => {
+            return new_th
+                .last_return
+                .on_return(ThResult::ThIoError, Error::Utf8Error(err))
+        }
     };
     let f = match File::open(filename) {
         Ok(f) => f,
-        Err(err) => return new_th.last_return.on_return(ThResult::ThIoError, Error::IoError(err)),
+        Err(err) => {
+            return new_th
+                .last_return
+                .on_return(ThResult::ThIoError, Error::IoError(err))
+        }
     };
     match super::Th::parse(ThBufReader::new(f)) {
         Ok(th) => new_th.teehistorian = Some(th),
@@ -335,21 +357,19 @@ pub extern "C" fn th_open(filename: *const c_char, th: &mut *mut Teehistorian) -
 /// `th_step()` has been called once
 pub extern "C" fn th_header(th: &mut Teehistorian, header: &mut *const c_char) -> ThResult {
     match th.teehistorian.as_mut() {
-        Some(parser) => {
-            match parser.header() {
-                Ok(h) => {
-                    *header = h.as_ptr() as *const c_char;
-                    return th.last_return.on_return(ThResult::ThOk, Error::None);
-                }
-                Err(err) => {
-                    return th.last_return.handle_error(err);
-                }
+        Some(parser) => match parser.header() {
+            Ok(h) => {
+                *header = h.as_ptr() as *const c_char;
+                return th.last_return.on_return(ThResult::ThOk, Error::None);
+            }
+            Err(err) => {
+                return th.last_return.handle_error(err);
             }
         },
-        None =>  {
+        None => {
             *header = 0 as *const c_char;
             return th.last_return.on_return(ThResult::ThMisuse, Error::None);
-        },
+        }
     }
 }
 
@@ -359,20 +379,18 @@ pub extern "C" fn th_header(th: &mut Teehistorian, header: &mut *const c_char) -
 pub extern "C" fn th_step(th: &'static mut Teehistorian, chunk: &mut *const Chunk) -> ThResult {
     th.chunk_str.clear();
     match th.teehistorian.as_mut() {
-        Some(parser) => {
-            match parser.next_chunk() {
-                Ok(rust_chunk) => {
-                    th.last_c_chunk = Some(Teehistorian::convert_chunk(&rust_chunk, &mut th.args));
-                    th.last_chunk = Some(rust_chunk);
-                    *chunk = th.last_c_chunk.as_ref().unwrap();
-                    return th.last_return.on_return(ThResult::ThOk, Error::None);
-                }
-                Err(err) => return th.last_return.handle_error(err),
+        Some(parser) => match parser.next_chunk() {
+            Ok(rust_chunk) => {
+                th.last_c_chunk = Some(Teehistorian::convert_chunk(&rust_chunk, &mut th.args));
+                th.last_chunk = Some(rust_chunk);
+                *chunk = th.last_c_chunk.as_ref().unwrap();
+                return th.last_return.on_return(ThResult::ThOk, Error::None);
             }
+            Err(err) => return th.last_return.handle_error(err),
         },
-        None =>  {
+        None => {
             return th.last_return.on_return(ThResult::ThMisuse, Error::None);
-        },
+        }
     };
 }
 
@@ -382,7 +400,9 @@ pub extern "C" fn th_step(th: &'static mut Teehistorian, chunk: &mut *const Chun
 /// deallocated.
 #[no_mangle]
 pub extern "C" fn th_close(th: *mut Teehistorian) {
-    unsafe { Box::from_raw(th); }
+    unsafe {
+        Box::from_raw(th);
+    }
 }
 
 /// Error Messages
@@ -397,8 +417,18 @@ pub extern "C" fn th_errmsg(th: &mut Teehistorian) -> *const c_char {
     match th.last_return.value {
         ThOk => write!(th.error_str, "No error occured\0").unwrap(),
         ThEof => write!(th.error_str, "Reached end of file\0").unwrap(),
-        ThIoError => write!(th.error_str, "Failed to open file: {}\0", th.last_return.error).unwrap(),
-        ThParseError => write!(th.error_str, "Error parsing file: {}\0", th.last_return.error).unwrap(),
+        ThIoError => write!(
+            th.error_str,
+            "Failed to open file: {}\0",
+            th.last_return.error
+        )
+        .unwrap(),
+        ThParseError => write!(
+            th.error_str,
+            "Error parsing file: {}\0",
+            th.last_return.error
+        )
+        .unwrap(),
         ThMisuse => write!(th.error_str, "Misuse: {}\0", th.last_return.error).unwrap(),
     }
     th.error_str.as_ptr() as *const c_char
@@ -419,4 +449,4 @@ pub extern "C" fn th_chunk_desc(th: &mut Teehistorian) -> *const c_char {
         }
     }
     th.chunk_str.as_ptr() as *const c_char
-}
\ No newline at end of file
+}
