@@ -1,10 +1,10 @@
-use crate::parser::{cstring, twint, uuid};
-use uuid::Uuid;
-use nom::IResult;
-use nom::multi::count;
-use nom::bytes::streaming::take;
-use nom::Err::Failure;
 use crate::error::ErrorKind;
+use crate::parser::{cstring, twint, uuid};
+use nom::bytes::streaming::take;
+use nom::multi::count;
+use nom::Err::Failure;
+use nom::IResult;
+use uuid::Uuid;
 
 fn player_input(input: &[u8]) -> IResult<&[u8], [i32; 10], ErrorKind> {
     let (input, i0) = twint(input)?;
@@ -84,7 +84,7 @@ pub struct ConsoleCommand<'a> {
     pub flags: i32,
     pub cmd: &'a [u8],
     pub num_args: i32,
-    pub args: Vec<&'a [u8]>
+    pub args: Vec<&'a [u8]>,
 }
 
 #[derive(Debug, PartialEq)]
@@ -202,13 +202,15 @@ pub enum Chunk<'a> {
     PlayerTeam(PlayerTeam),
     /// `teehistorian-team-practice@ddnet.tw`
     TeamPractice(TeamPractice),
+    /// `teehistorian-player-ready@ddnet.tw`
+    PlayerReady(PlayerId),
 }
 
 fn chunk_player_diff(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     let (input, dx) = twint(input)?;
     let (input, dy) = twint(input)?;
-    Ok((input, Chunk::PlayerDiff(PlayerDiff {cid, dx, dy})))
+    Ok((input, Chunk::PlayerDiff(PlayerDiff { cid, dx, dy })))
 }
 fn chunk_tick_skip(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, dt) = twint(input)?;
@@ -232,7 +234,13 @@ fn chunk_input_diff(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
 fn chunk_input_new(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     let (input, player_input) = player_input(input)?;
-    Ok((input, Chunk::InputNew(InputNew { cid, input: player_input })))
+    Ok((
+        input,
+        Chunk::InputNew(InputNew {
+            cid,
+            input: player_input,
+        }),
+    ))
 }
 fn chunk_net_message(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
@@ -262,7 +270,16 @@ fn chunk_console_command(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
         return Err(Failure(ErrorKind::NegativeBufLen(num_args)));
     }
     let (input, args) = count(cstring, num_args as usize)(input)?;
-    Ok((input, Chunk::ConsoleCommand(ConsoleCommand { cid, flags, cmd, num_args, args })))
+    Ok((
+        input,
+        Chunk::ConsoleCommand(ConsoleCommand {
+            cid,
+            flags,
+            cmd,
+            num_args,
+            args,
+        }),
+    ))
 }
 
 /// `teehistorian-test@ddnet.tw`
@@ -300,9 +317,15 @@ const TH_PLAYER_TEAM: Uuid = Uuid::from_u128(0xa111c04e_1ea8_38e0_90b1_d7f993ca0
 /// `teehistorian-team-practice@ddnet.tw`
 const TH_TEAM_PRACTICE: Uuid = Uuid::from_u128(0x5792834e_81d1_34c9_a29b_b5ff25dac3bc);
 
+/// `teehistorian-player-ready@ddnet.tw`
+const TH_PLAYER_READY: Uuid = Uuid::from_u128(0x638587c9_3f75_3887_918e_a3c2614ffaa0);
+
 fn extension_test(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     if !input.is_empty() {
-        Err(Failure(ErrorKind::TrailingBytes("EX_TEST", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_TEST",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::Test))
     }
@@ -311,9 +334,15 @@ fn extension_ddnetver_old(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     let (input, version) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_DDNETVER_OLD", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_DDNETVER_OLD",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::DdnetVersionOld(DdnetVersionOld { cid, version })))
+        Ok((
+            input,
+            Chunk::DdnetVersionOld(DdnetVersionOld { cid, version }),
+        ))
     }
 }
 fn extension_ddnetver(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
@@ -322,9 +351,20 @@ fn extension_ddnetver(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, version) = twint(input)?;
     let (input, version_str) = cstring(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_DDNETVER", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_DDNETVER",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::DdnetVersion(DdnetVersion { cid, connection_id, version, version_str })))
+        Ok((
+            input,
+            Chunk::DdnetVersion(DdnetVersion {
+                cid,
+                connection_id,
+                version,
+                version_str,
+            }),
+        ))
     }
 }
 fn extension_auth_init(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
@@ -332,9 +372,19 @@ fn extension_auth_init(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, level) = twint(input)?;
     let (input, auth_name) = cstring(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_AUTH_INIT", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_AUTH_INIT",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::AuthInit(Auth { cid, level, auth_name })))
+        Ok((
+            input,
+            Chunk::AuthInit(Auth {
+                cid,
+                level,
+                auth_name,
+            }),
+        ))
     }
 }
 fn extension_auth_login(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
@@ -342,15 +392,28 @@ fn extension_auth_login(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, level) = twint(input)?;
     let (input, auth_name) = cstring(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_AUTH_INIT", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_AUTH_INIT",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::AuthInit(Auth { cid, level, auth_name })))
+        Ok((
+            input,
+            Chunk::AuthInit(Auth {
+                cid,
+                level,
+                auth_name,
+            }),
+        ))
     }
 }
 fn extension_auth_logout(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_AUTH_LOGOUT", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_AUTH_LOGOUT",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::AuthLogout(AuthLogout { cid })))
     }
@@ -358,7 +421,10 @@ fn extension_auth_logout(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
 fn extension_join_ver6(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_JOINVER6", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_JOINVER6",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::JoinVer6(PlayerId { cid })))
     }
@@ -366,7 +432,10 @@ fn extension_join_ver6(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
 fn extension_join_ver7(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_JOINVER7", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_JOINVER7",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::JoinVer7(PlayerId { cid })))
     }
@@ -376,15 +445,28 @@ fn extension_save_success(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, save_id) = uuid(input)?;
     let (input, save) = cstring(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_SAVE_SUCCESS", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_SAVE_SUCCESS",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::TeamSaveSuccess(TeamSave { team, save_id, save })))
+        Ok((
+            input,
+            Chunk::TeamSaveSuccess(TeamSave {
+                team,
+                save_id,
+                save,
+            }),
+        ))
     }
 }
 fn extension_save_failure(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, team) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_SAVE_FAILURE", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_SAVE_FAILURE",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::TeamSaveFailure(Team { team })))
     }
@@ -394,15 +476,28 @@ fn extension_load_success(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, save_id) = uuid(input)?;
     let (input, save) = cstring(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_LOAD_SUCCESS", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_LOAD_SUCCESS",
+            input.len() as u32,
+        )))
     } else {
-        Ok((input, Chunk::TeamLoadSuccess(TeamSave { team, save_id, save })))
+        Ok((
+            input,
+            Chunk::TeamLoadSuccess(TeamSave {
+                team,
+                save_id,
+                save,
+            }),
+        ))
     }
 }
 fn extension_load_failure(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, team) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_LOAD_FAILURE", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_LOAD_FAILURE",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::TeamLoadFailure(Team { team })))
     }
@@ -411,7 +506,10 @@ fn extension_player_team(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, cid) = twint(input)?;
     let (input, team) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_PLAYER_TEAM", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_PLAYER_TEAM",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::PlayerTeam(PlayerTeam { cid, team })))
     }
@@ -420,11 +518,25 @@ fn extension_team_practice(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, team) = twint(input)?;
     let (input, practice) = twint(input)?;
     if input != b"" {
-        Err(Failure(ErrorKind::TrailingBytes("EX_PLAYER_TEAM", input.len() as u32)))
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_TEAM_PRACTICE",
+            input.len() as u32,
+        )))
     } else {
         Ok((input, Chunk::TeamPractice(TeamPractice { team, practice })))
     }
 }
+fn extension_player_ready(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
+    let (input, cid) = twint(input)?;
+    if input != b"" {
+        Err(Failure(ErrorKind::TrailingBytes(
+            "EX_PLAYER_READY",
+            input.len() as u32,
+        )))
+    } else {
+        Ok((input, Chunk::PlayerReady(PlayerId { cid })))
+    }
+}
 
 fn chunk_unknown_ex(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
     let (input, uuid) = uuid(input)?;
@@ -448,7 +560,8 @@ fn chunk_unknown_ex(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
         TH_LOAD_FAILURE => { extension_load_failure(data) }?,
         TH_PLAYER_TEAM => { extension_player_team(data) }?,
         TH_TEAM_PRACTICE => { extension_team_practice(data) }?,
-        _ => (input, Chunk::UnknownEx(UnknownEx { uuid, size, data }))
+        TH_PLAYER_READY => { extension_player_ready(data) }?,
+        _ => (input, Chunk::UnknownEx(UnknownEx { uuid, size, data })),
     };
     Ok((input, c))
 }
@@ -470,4 +583,4 @@ pub fn chunk(input: &[u8]) -> IResult<&[u8], Chunk, ErrorKind> {
         -11 => chunk_unknown_ex(i),
         other => Err(Failure(ErrorKind::UnknownTag(other))),
     }
-}
\ No newline at end of file
+}
