@@ -28,7 +28,10 @@ impl fmt::Display for Error {
         match self {
             Error::ParseError(err) => write!(f, "{}", err),
             Error::IoError(err) => write!(f, "IoError: {}", err),
-            Error::Eof => write!(f, "Tried to parse chunk but reached EOF before completely parsing the chunk")
+            Error::Eof => write!(
+                f,
+                "Tried to parse chunk but reached EOF before completely parsing the chunk"
+            ),
         }
     }
 }
