@@ -41,20 +41,20 @@
 //! ```
 //!
 
-mod parser;
 pub mod chunks;
 mod error;
+mod parser;
 
-pub use error::{Error, ErrorKind};
-pub use chunks::Chunk;
 pub use bufread::{ThBufRead, ThBufReader};
+pub use chunks::Chunk;
+pub use error::{Error, ErrorKind};
 
-#[cfg(feature="capi")]
-mod capi;
 mod bufread;
+#[cfg(feature = "capi")]
+mod capi;
 
-use uuid::Uuid;
 use crate::parser::cstring;
+use uuid::Uuid;
 
 #[derive(Debug)]
 pub struct Th<T: ThBufRead> {
@@ -114,19 +114,20 @@ impl<T: ThBufRead> Th<T> {
             match cstring(buf) {
                 Ok((new_input, header)) => {
                     // safe since computing difference to subslice
-                    self.num_consume = unsafe { new_input.as_ptr().offset_from(buf.as_ptr()) } as usize;
+                    self.num_consume =
+                        unsafe { new_input.as_ptr().offset_from(buf.as_ptr()) } as usize;
                     return Ok(header);
                 }
                 Err(nom::Err::Error(err)) | Err(nom::Err::Failure(err)) => {
                     self.num_consume = 0;
                     return Err(err.into());
-                },
+                }
                 Err(nom::Err::Incomplete(_)) => {
                     if self.buf.fill_buf()? == 0 {
                         // End of file
                         return Err(crate::error::Error::Eof);
                     }
-                },
+                }
             }
         }
     }
@@ -149,20 +150,21 @@ impl<T: ThBufRead> Th<T> {
             match chunks::chunk(buf) {
                 Ok((new_input, chunk)) => {
                     // safe since computing difference to subslice
-                    self.num_consume = unsafe { new_input.as_ptr().offset_from(buf.as_ptr()) } as usize;
+                    self.num_consume =
+                        unsafe { new_input.as_ptr().offset_from(buf.as_ptr()) } as usize;
                     return Ok(chunk);
                 }
                 Err(nom::Err::Error(err)) | Err(nom::Err::Failure(err)) => {
                     self.num_consume = 0;
                     return Err(err.into());
-                },
+                }
                 Err(nom::Err::Incomplete(_)) => {
                     if self.buf.fill_buf()? == 0 {
                         // End of file
                         return Err(crate::error::Error::Eof);
                     }
-                },
+                }
             }
         }
     }
-}
\ No newline at end of file
+}
